pub enum WaitPolicy {
WaitFor(Duration),
NoWait,
}Expand description
Defines the wait policy for index creation.
Variants
WaitFor(Duration)
Wait for the index to become ready, up to the specified duration.
NoWait
Do not wait for the index to become ready – return immediately.